@@ -5,6 +5,7 @@
 #' @param file_id the id number of the file, if removing an attached file from a fileset.  
 #'   file_id defaults to NULL, removing the entire draft or private article. 
 #' @param session (optional) the authentication credentials from \code{\link{fs_auth}}. If not provided, will attempt to load from cache as long as figshare_auth has been run.  
+#' @param debug display return value of request?
 #' @return output of DELETE request (invisibly) 
 #' @seealso \code{\link{fs_auth}}
 #' @references \url{http://api.figshare.com}
@@ -22,14 +23,15 @@
 
 #' }
 fs_delete <- 
-function(article_id, file_id = NULL, session = fs_get_auth()){
+function(article_id, file_id = NULL, session = fs_get_auth(), debug = FALSE){
   base <- "http://api.figshare.com/v1"
-  method <- paste("my_data/articles", article_id, sep= "/")
+  method <- paste("my_data/articles", article_id, sep = "/")
   if(!is.null(file_id))
-    method <- paste(method, "files", file_id, sep="/")
-  request <- paste(base, method, sep="/")
-  config = c(verbose(), session)
-  del <- DELETE(request, config=config)
+    method <- paste(method, "files", file_id, sep = "/")
+  request <- paste(base, method, sep = "/")
+  config <- config(token = session)
+  del <- DELETE(request, config = config)
+  if(debug | del$status_code != 200)
   invisible(del)
 }
 
